<?php
/*
This file is part of Formol.

Formol is free software; you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation; either version 3 of the License, or
(at your option) any later version.

Formol is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

/**
 * FormManager class
 *
 * Manages form changes
 *
 * @copyright Copyright (c) 2007 Thomas Mazière
 * @author Thomas Mazière <thomas.maziere@gmail.com>
 * @package formol
 */

class FormManager
{

	/**
	 * form to manage
	 *
	 * @var object Form
	 */
	protected  $_form;
	
	
	/**
	 * Constructor
	 *
	 * @return bool
	 */

	public function __construct(Form $form) {
		$this->_form = $form;
	}

	/**
	 * Update all fields
	 *
	 * @return string
	 */

	public function update($postVars) {
		$ignore = array('InputRadio', 'InputCheckbox', 'InputSubmit', 'InputImage', 'InputButton');
		foreach ($this->_form as $field) {
			if  ($field->enabled != false && $field->type != "InputFile") {
				if (isset($postVars[$field->name])) {
					$newValue = $postVars[$field->name];
					// Each PreProcessor modifies submitted value
					foreach ($field->preProcessors as $processor) {
						if (is_callable(array(self, $processor))) {
							$newValue = $this->$processor($newValue);
						} else if (is_callable($processor)) {
							$newValue = $processor($newValue);
						} else {
							throw new FormException("Process unknown : '".htmlentities($processor)."'");
						}
					}				
					$field->value = $newValue;
				} else if (in_array($field->type, $ignore)) {
					continue;
				} else {
					throw new FormException("Cannot update field '".$field->name."' : no value provided");
				}
			}
		}
	}
	
	/**
	 * Validates all fields
	 *
	 * @return bool
	 */

	public function validate() {
		$this->_form->errors = array();
		foreach ($this->_form as $field) {
			// Each Validator add error message if testing fails
			$field->errors = array();
			foreach ($field->validators as $validator) {
				$class = $validator[0].'Validator';
				if (class_exists($class)) {
					$valid = new $class($field, $validator[1], $validator[2]);
					$valid->validate();
				}				
			}	
			if (count($field->errors) > 0) {
				$this->_form->errors[] = $field->errors[0];
			}
		}
		$validated = (count($this->_form->errors) > 0) ? false : true;
		return $validated;
	}	

}
?>
