<?php
/**
 * FieldRenderer class
 *
 * Manages field rendering
 *
 * @copyright Copyright (c) 2007 Thomas Mazière
 * @author Thomas Mazière <thomas.maziere@gmail.com>
 * @package formol
 */

abstract class FieldRenderer
{

	/**
	 * field to render
	 *
	 * @var object Field
	 */
	protected  $_field;
	
	/**
	 * XHTML pattern
	 * ex : <div class="line">{{label}}&nbsp;{{field}}</div>
	 *
	 * @var string
	 */
	protected  $_xhtmlPattern;

	/**
	 * Array of options (type "radio", "select" for ex.)
	 *
	 * @var array
	 */
	protected  $_options;

	
	
	/**
	 * Constructor
	 *
	 * @return bool
	 */

	public function __construct(Field $field, $pattern = '') {
		$this->_field = $field;
		$this->_xhtmlPattern = $pattern;
	}
	
	/**
	 * sets xhtml pattern
	 *
	 * @return bool
	 */

	public function setXhtmlPattern($pattern) {
		$this->_xhtmlPattern = $pattern;
	}

	/**
	 * Renders complete field (HTML, label + field, with xhtml pattern if defined)
	 *
	 * @abstract
	 * @return string
	 */

	public abstract function render($args) ;

	/**
	 * Renders label (HTML, label only)
	 *
	 * @abstract
	 * @return string
	 */

	public abstract function renderLabel() ;

	/**
	 * Renders field (HTML, field only)
	 *
	 * @abstract
	 * @return string
	 */

	public abstract  function renderField($args) ;

}
?>
