<?php
/**
 * InputRadioRenderer class
 *
 * Render Input:Radio fields
 *
 * @copyright Copyright (c) 2007 Thomas Mazière
 * @author Thomas Mazière <thomas.maziere@gmail.com>
 * @package formol
 */
require_once('FieldRenderer.class.php');

class InputRadioRenderer extends FieldRenderer
{


	/**
	 * Render whole field
	 *
	 * @return string
	 */

	public final function render($args) {
		if (count($args['options']) == 0) {
			throw new FormException("Cannot render this field : no options provided");
		}
		if ($this->_xhtmlPattern != '') {
			$xhtml = $this->_xhtmlPattern;
			$xhtml = str_replace('{{label}}', $this->renderLabel(), $xhtml);
			$xhtml = str_replace('{{field}}', $this->renderField($args), $xhtml);
			return $xhtml;
		} else {
			$xhtml = $this->renderLabel().$this->renderField($args);
			return $xhtml;
		}
	}


	/**
	 * @access public
	 * @return string
	 */

	public final function renderLabel() {
		$class = ($this->_field->labelClass != '') ? " class=\"".$this->_field->labelClass."\"" : "";
		return "\n<span".$class.">".$this->_field->label."</span>\n";
	}


	/**
	 * @access public
	 * @return string
	 */

	public final function renderField($args) {
		if (count($args['options']) == 0) {
			throw new FormException("Cannot render this field : no options provided");
		}
		$opt = '';
		$class = ($this->_field->fieldClass != '') ? " class=\"".$this->_field->fieldClass."\"" : "";
		$disabled = ($this->_field->enabled == false) ? " disabled=\"disabled\"" : "";
		$optNum = 1;
		foreach ($args['options'] as $val => $option) {
			$checked = ($val == $this->_field->value) ? " checked=\"checked\"" : "";
			$opt .= "\n<input type=\"radio\" name=\"".$this->_field->name."\" id=\"".$this->_field->name."_".$optNum."\" value=\"".$val."\"".$checked." /><label for=\"".$this->_field->name."_".$optNum."\">".$option."</label>".$args['sep'];
			$optNum++;
		}
		
		
		return "\n".$opt."\n";
	}

}
?>
